@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Mail::Milter::Authentication::Pragmas;
 # ABSTRACT: Milter protocol handling
-our $VERSION = '3.20220131'; # VERSION
+our $VERSION = '3.20220914'; # VERSION
 use Net::IP;
 
 sub register_metrics {
@@ -203,7 +203,7 @@ sub milter_process_command {
                 }
                 else {
                     $handler->metric_count( 'mail_processed_total', { 'result' => 'deferred' } );
-                    $self->loginfo ( "SMTPDefer: $reject_reason" );
+                    $self->loginfo ( "SMTPDefer: $defer_reason" );
                     $self->write_packet( SMFIR_REPLYCODE,
                         $defer_reason
                         . "\0"
@@ -349,7 +349,7 @@ Mail::Milter::Authentication::Protocol::Milter - Milter protocol handling
 
 =head1 VERSION
 
-version 3.20220131
+version 3.20220914
 
 =head1 SYNOPSIS
 
